@@ -74,6 +74,11 @@ namespace Beagle.Filters {
 		};
 
 		public FilterMPlayerVideo ()
+		{
+			PreLoad = false;
+		}
+
+		protected override void RegisterSupportedTypes ()
 		{
 			foreach (string s in mime_types) {
 				FilterFlavor flavor = FilterFlavor.NewFromMimeType (s);
@@ -81,8 +86,6 @@ namespace Beagle.Filters {
 
 				AddSupportedFlavor (flavor);
 			}
-
-			PreLoad = false;
 		}
 		
 		private string AspectString(float aspect) {
@@ -112,6 +115,13 @@ namespace Beagle.Filters {
 			pc.RedirectStandardOutput = true;
 			pc.RedirectStandardError = true;
 
+			// Let mplayer run for 10 seconds, max.
+			pc.CpuLimit = 10;
+
+			// There have been reports of mplayer eating tons of
+			// memory.  So limit it to 100 megs too.
+			pc.MemLimit = 100*1024*1024;
+
 			try {
 				pc.Start ();
 			} catch (SafeProcessException e) {
@@ -122,7 +132,7 @@ namespace Beagle.Filters {
 
 			StreamReader pout = new StreamReader (pc.StandardOutput);
 			string str;
-			string name = "";
+			string name = String.Empty;
 			
 			while ((str = pout.ReadLine ()) != null) {
 				if (!str.StartsWith ("ID_"))
